import java.rmi
import java.rmi.server
import typing



class LocateRegistry:
    @typing.overload
    @staticmethod
    def createRegistry(int: int) -> 'Registry': ...
    @typing.overload
    @staticmethod
    def createRegistry(int: int, rMIClientSocketFactory: java.rmi.server.RMIClientSocketFactory, rMIServerSocketFactory: java.rmi.server.RMIServerSocketFactory) -> 'Registry': ...
    @typing.overload
    @staticmethod
    def getRegistry() -> 'Registry': ...
    @typing.overload
    @staticmethod
    def getRegistry(int: int) -> 'Registry': ...
    @typing.overload
    @staticmethod
    def getRegistry(string: str) -> 'Registry': ...
    @typing.overload
    @staticmethod
    def getRegistry(string: str, int: int) -> 'Registry': ...
    @typing.overload
    @staticmethod
    def getRegistry(string: str, int: int, rMIClientSocketFactory: java.rmi.server.RMIClientSocketFactory) -> 'Registry': ...

class Registry(java.rmi.Remote):
    REGISTRY_PORT: typing.ClassVar[int] = ...
    def bind(self, string: str, remote: java.rmi.Remote) -> None: ...
    def list(self) -> typing.List[str]: ...
    def lookup(self, string: str) -> java.rmi.Remote: ...
    def rebind(self, string: str, remote: java.rmi.Remote) -> None: ...
    def unbind(self, string: str) -> None: ...

class RegistryHandler:
    def registryImpl(self, int: int) -> Registry: ...
    def registryStub(self, string: str, int: int) -> Registry: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.rmi.registry")``.

    LocateRegistry: typing.Type[LocateRegistry]
    Registry: typing.Type[Registry]
    RegistryHandler: typing.Type[RegistryHandler]



import java.lang
import scala.annotation.meta
import scala.annotation.unchecked
import scala.collection.immutable
import typing



class Annotation:
    def __init__(self): ...

class StaticAnnotation: ...

class TypeConstraint: ...

class ClassfileAnnotation(StaticAnnotation): ...

class bridge(Annotation, StaticAnnotation):
    def __init__(self): ...

class compileTimeOnly(Annotation, StaticAnnotation):
    def __init__(self, message: typing.Union[java.lang.String, str]): ...

class elidable(Annotation, StaticAnnotation):
    def __init__(self, level: int): ...
    @staticmethod
    def ALL() -> int: ...
    @staticmethod
    def ASSERTION() -> int: ...
    @staticmethod
    def CONFIG() -> int: ...
    @staticmethod
    def FINE() -> int: ...
    @staticmethod
    def FINER() -> int: ...
    @staticmethod
    def FINEST() -> int: ...
    @staticmethod
    def INFO() -> int: ...
    @staticmethod
    def MAXIMUM() -> int: ...
    @staticmethod
    def MINIMUM() -> int: ...
    @staticmethod
    def OFF() -> int: ...
    @staticmethod
    def SEVERE() -> int: ...
    @staticmethod
    def WARNING() -> int: ...
    @staticmethod
    def byName() -> scala.collection.immutable.Map[java.lang.String, typing.Any]: ...
    def level(self) -> int: ...

class implicitAmbiguous(Annotation, StaticAnnotation):
    def __init__(self, msg: typing.Union[java.lang.String, str]): ...

class implicitNotFound(Annotation, StaticAnnotation):
    def __init__(self, msg: typing.Union[java.lang.String, str]): ...

class migration(Annotation, StaticAnnotation):
    def __init__(self, message: typing.Union[java.lang.String, str], changedIn: typing.Union[java.lang.String, str]): ...

class showAsInfix(Annotation, StaticAnnotation):
    def __init__(self, enabled: bool): ...
    @staticmethod
    def $lessinit$greater$default$1() -> bool: ...

class strictfp(Annotation, StaticAnnotation):
    def __init__(self): ...

class switch(Annotation, StaticAnnotation):
    def __init__(self): ...

class tailrec(Annotation, StaticAnnotation):
    def __init__(self): ...

class unspecialized(Annotation, StaticAnnotation):
    def __init__(self): ...

class varargs(Annotation, StaticAnnotation):
    def __init__(self): ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.annotation")``.

    Annotation: typing.Type[Annotation]
    ClassfileAnnotation: typing.Type[ClassfileAnnotation]
    StaticAnnotation: typing.Type[StaticAnnotation]
    TypeConstraint: typing.Type[TypeConstraint]
    bridge: typing.Type[bridge]
    compileTimeOnly: typing.Type[compileTimeOnly]
    elidable: typing.Type[elidable]
    implicitAmbiguous: typing.Type[implicitAmbiguous]
    implicitNotFound: typing.Type[implicitNotFound]
    migration: typing.Type[migration]
    showAsInfix: typing.Type[showAsInfix]
    strictfp: typing.Type[strictfp]
    switch: typing.Type[switch]
    tailrec: typing.Type[tailrec]
    unspecialized: typing.Type[unspecialized]
    varargs: typing.Type[varargs]
    meta: scala.annotation.meta.__module_protocol__
    unchecked: scala.annotation.unchecked.__module_protocol__



import typing



class Platform:
    @staticmethod
    def EOL() -> str: ...
    @staticmethod
    def arrayclear(arr: typing.List[int]) -> None: ...
    @staticmethod
    def arraycopy(src: typing.Any, srcPos: int, dest: typing.Any, destPos: int, length: int) -> None: ...
    @staticmethod
    def collectGarbage() -> None: ...
    @staticmethod
    def createArray(elemClass: typing.Type[typing.Any], length: int) -> typing.Any: ...
    @staticmethod
    def currentTime() -> int: ...
    @staticmethod
    def defaultCharsetName() -> str: ...
    @staticmethod
    def getClassForName(name: str) -> typing.Type[typing.Any]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.compat")``.

    Platform: typing.Type[Platform]



import java.lang.ref
import scala
import typing



_Reference__T = typing.TypeVar('_Reference__T')  # <T>
class Reference(scala.Function0[_Reference__T], typing.Generic[_Reference__T]):
    @staticmethod
    def $init$($this: 'Reference') -> None: ...
    def apply(self) -> _Reference__T: ...
    def clear(self) -> None: ...
    def enqueue(self) -> bool: ...
    def get(self) -> scala.Option[_Reference__T]: ...
    def isEnqueued(self) -> bool: ...
    def toString(self) -> str: ...

_ReferenceQueue__T = typing.TypeVar('_ReferenceQueue__T')  # <T>
class ReferenceQueue(typing.Generic[_ReferenceQueue__T]):
    def __init__(self): ...
    def Wrapper(self, jref: java.lang.ref.Reference[typing.Any]) -> scala.Option[Reference[_ReferenceQueue__T]]: ...
    def poll(self) -> scala.Option[Reference[_ReferenceQueue__T]]: ...
    @typing.overload
    def remove(self) -> scala.Option[Reference[_ReferenceQueue__T]]: ...
    @typing.overload
    def remove(self, timeout: int) -> scala.Option[Reference[_ReferenceQueue__T]]: ...
    def toString(self) -> str: ...
    def underlying(self) -> java.lang.ref.ReferenceQueue[_ReferenceQueue__T]: ...

_ReferenceWithWrapper__T = typing.TypeVar('_ReferenceWithWrapper__T')  # <T>
class ReferenceWithWrapper(typing.Generic[_ReferenceWithWrapper__T]):
    def wrapper(self) -> 'ReferenceWrapper'[_ReferenceWithWrapper__T]: ...

_PhantomReferenceWithWrapper__T = typing.TypeVar('_PhantomReferenceWithWrapper__T')  # <T>
class PhantomReferenceWithWrapper(java.lang.ref.PhantomReference[_PhantomReferenceWithWrapper__T], ReferenceWithWrapper[_PhantomReferenceWithWrapper__T], typing.Generic[_PhantomReferenceWithWrapper__T]):
    def __init__(self, value: _PhantomReferenceWithWrapper__T, queue: ReferenceQueue[_PhantomReferenceWithWrapper__T], wrapper: 'PhantomReference'[_PhantomReferenceWithWrapper__T]): ...
    def wrapper(self) -> 'PhantomReference'[_PhantomReferenceWithWrapper__T]: ...

_ReferenceWrapper__T = typing.TypeVar('_ReferenceWrapper__T')  # <T>
class ReferenceWrapper(Reference[_ReferenceWrapper__T], scala.Proxy, typing.Generic[_ReferenceWrapper__T]):
    @staticmethod
    def $init$($this: 'ReferenceWrapper') -> None: ...
    def apply(self) -> _ReferenceWrapper__T: ...
    def clear(self) -> None: ...
    def enqueue(self) -> bool: ...
    def equals(self, that: typing.Any) -> bool: ...
    def get(self) -> scala.Option[_ReferenceWrapper__T]: ...
    def hashCode(self) -> int: ...
    def isEnqueued(self) -> bool: ...
    @typing.overload
    def self(self) -> typing.Any: ...
    @typing.overload
    def self(self) -> java.lang.ref.Reference[_ReferenceWrapper__T]: ...
    @typing.overload
    def toString(self) -> str: ...
    @typing.overload
    def toString(self) -> str: ...
    def underlying(self) -> java.lang.ref.Reference[_ReferenceWrapper__T]: ...

_SoftReferenceWithWrapper__T = typing.TypeVar('_SoftReferenceWithWrapper__T')  # <T>
class SoftReferenceWithWrapper(java.lang.ref.SoftReference[_SoftReferenceWithWrapper__T], ReferenceWithWrapper[_SoftReferenceWithWrapper__T], typing.Generic[_SoftReferenceWithWrapper__T]):
    def __init__(self, value: _SoftReferenceWithWrapper__T, queue: ReferenceQueue[_SoftReferenceWithWrapper__T], wrapper: 'SoftReference'[_SoftReferenceWithWrapper__T]): ...
    def wrapper(self) -> 'SoftReference'[_SoftReferenceWithWrapper__T]: ...

_WeakReferenceWithWrapper__T = typing.TypeVar('_WeakReferenceWithWrapper__T')  # <T>
class WeakReferenceWithWrapper(java.lang.ref.WeakReference[_WeakReferenceWithWrapper__T], ReferenceWithWrapper[_WeakReferenceWithWrapper__T], typing.Generic[_WeakReferenceWithWrapper__T]):
    def __init__(self, value: _WeakReferenceWithWrapper__T, queue: ReferenceQueue[_WeakReferenceWithWrapper__T], wrapper: 'WeakReference'[_WeakReferenceWithWrapper__T]): ...
    def wrapper(self) -> 'WeakReference'[_WeakReferenceWithWrapper__T]: ...

_PhantomReference__T = typing.TypeVar('_PhantomReference__T')  # <T>
class PhantomReference(ReferenceWrapper[_PhantomReference__T], typing.Generic[_PhantomReference__T]):
    def __init__(self, value: _PhantomReference__T, queue: ReferenceQueue[_PhantomReference__T]): ...
    def apply(self) -> _PhantomReference__T: ...
    def apply$mcB$sp(self) -> int: ...
    def apply$mcC$sp(self) -> str: ...
    def apply$mcD$sp(self) -> float: ...
    def apply$mcF$sp(self) -> float: ...
    def apply$mcI$sp(self) -> int: ...
    def apply$mcJ$sp(self) -> int: ...
    def apply$mcS$sp(self) -> int: ...
    def apply$mcV$sp(self) -> None: ...
    def apply$mcZ$sp(self) -> bool: ...
    def clear(self) -> None: ...
    def enqueue(self) -> bool: ...
    def equals(self, that: typing.Any) -> bool: ...
    def get(self) -> scala.Option[_PhantomReference__T]: ...
    def hashCode(self) -> int: ...
    def isEnqueued(self) -> bool: ...
    def self(self) -> java.lang.ref.Reference[_PhantomReference__T]: ...
    def toString(self) -> str: ...
    def underlying(self) -> java.lang.ref.PhantomReference[_PhantomReference__T]: ...

_SoftReference__T = typing.TypeVar('_SoftReference__T')  # <T>
class SoftReference(ReferenceWrapper[_SoftReference__T], typing.Generic[_SoftReference__T]):
    @typing.overload
    def __init__(self, value: _SoftReference__T): ...
    @typing.overload
    def __init__(self, value: _SoftReference__T, queue: ReferenceQueue[_SoftReference__T]): ...
    def apply(self) -> _SoftReference__T: ...
    def apply$mcB$sp(self) -> int: ...
    def apply$mcC$sp(self) -> str: ...
    def apply$mcD$sp(self) -> float: ...
    def apply$mcF$sp(self) -> float: ...
    def apply$mcI$sp(self) -> int: ...
    def apply$mcJ$sp(self) -> int: ...
    def apply$mcS$sp(self) -> int: ...
    def apply$mcV$sp(self) -> None: ...
    def apply$mcZ$sp(self) -> bool: ...
    def clear(self) -> None: ...
    def enqueue(self) -> bool: ...
    def equals(self, that: typing.Any) -> bool: ...
    def get(self) -> scala.Option[_SoftReference__T]: ...
    def hashCode(self) -> int: ...
    def isEnqueued(self) -> bool: ...
    def self(self) -> java.lang.ref.Reference[_SoftReference__T]: ...
    def toString(self) -> str: ...
    _unapply__T = typing.TypeVar('_unapply__T')  # <T>
    @staticmethod
    def unapply(sr: 'SoftReference'[_unapply__T]) -> scala.Option[_unapply__T]: ...
    def underlying(self) -> java.lang.ref.SoftReference[_SoftReference__T]: ...

_WeakReference__T = typing.TypeVar('_WeakReference__T')  # <T>
class WeakReference(ReferenceWrapper[_WeakReference__T], typing.Generic[_WeakReference__T]):
    @typing.overload
    def __init__(self, value: _WeakReference__T): ...
    @typing.overload
    def __init__(self, value: _WeakReference__T, queue: ReferenceQueue[_WeakReference__T]): ...
    def apply(self) -> _WeakReference__T: ...
    def apply$mcB$sp(self) -> int: ...
    def apply$mcC$sp(self) -> str: ...
    def apply$mcD$sp(self) -> float: ...
    def apply$mcF$sp(self) -> float: ...
    def apply$mcI$sp(self) -> int: ...
    def apply$mcJ$sp(self) -> int: ...
    def apply$mcS$sp(self) -> int: ...
    def apply$mcV$sp(self) -> None: ...
    def apply$mcZ$sp(self) -> bool: ...
    def clear(self) -> None: ...
    def enqueue(self) -> bool: ...
    def equals(self, that: typing.Any) -> bool: ...
    def get(self) -> scala.Option[_WeakReference__T]: ...
    def hashCode(self) -> int: ...
    def isEnqueued(self) -> bool: ...
    def self(self) -> java.lang.ref.Reference[_WeakReference__T]: ...
    def toString(self) -> str: ...
    _unapply__T = typing.TypeVar('_unapply__T')  # <T>
    @staticmethod
    def unapply(wr: 'WeakReference'[_unapply__T]) -> scala.Option[_unapply__T]: ...
    def underlying(self) -> java.lang.ref.WeakReference[_WeakReference__T]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("scala.ref")``.

    PhantomReference: typing.Type[PhantomReference]
    PhantomReferenceWithWrapper: typing.Type[PhantomReferenceWithWrapper]
    Reference: typing.Type[Reference]
    ReferenceQueue: typing.Type[ReferenceQueue]
    ReferenceWithWrapper: typing.Type[ReferenceWithWrapper]
    ReferenceWrapper: typing.Type[ReferenceWrapper]
    SoftReference: typing.Type[SoftReference]
    SoftReferenceWithWrapper: typing.Type[SoftReferenceWithWrapper]
    WeakReference: typing.Type[WeakReference]
    WeakReferenceWithWrapper: typing.Type[WeakReferenceWithWrapper]



import java.lang
import java.math
import java.security
import java.security.interfaces
import typing



class AlgorithmParameterSpec: ...

class ECField:
    def getFieldSize(self) -> int: ...

class ECPoint:
    POINT_INFINITY: typing.ClassVar['ECPoint'] = ...
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getAffineX(self) -> java.math.BigInteger: ...
    def getAffineY(self) -> java.math.BigInteger: ...
    def hashCode(self) -> int: ...

class EllipticCurve:
    @typing.overload
    def __init__(self, eCField: ECField, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger): ...
    @typing.overload
    def __init__(self, eCField: ECField, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger, byteArray: typing.List[int]): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getA(self) -> java.math.BigInteger: ...
    def getB(self) -> java.math.BigInteger: ...
    def getField(self) -> ECField: ...
    def getSeed(self) -> typing.List[int]: ...
    def hashCode(self) -> int: ...

class InvalidKeySpecException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class InvalidParameterSpecException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class KeySpec: ...

class RSAOtherPrimeInfo:
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger, bigInteger3: java.math.BigInteger): ...
    def getCrtCoefficient(self) -> java.math.BigInteger: ...
    def getExponent(self) -> java.math.BigInteger: ...
    def getPrime(self) -> java.math.BigInteger: ...

class DSAGenParameterSpec(AlgorithmParameterSpec):
    @typing.overload
    def __init__(self, int: int, int2: int): ...
    @typing.overload
    def __init__(self, int: int, int2: int, int3: int): ...
    def getPrimePLength(self) -> int: ...
    def getSeedLength(self) -> int: ...
    def getSubprimeQLength(self) -> int: ...

class DSAParameterSpec(AlgorithmParameterSpec, java.security.interfaces.DSAParams):
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger, bigInteger3: java.math.BigInteger): ...
    def getG(self) -> java.math.BigInteger: ...
    def getP(self) -> java.math.BigInteger: ...
    def getQ(self) -> java.math.BigInteger: ...

class DSAPrivateKeySpec(KeySpec):
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger, bigInteger3: java.math.BigInteger, bigInteger4: java.math.BigInteger): ...
    def getG(self) -> java.math.BigInteger: ...
    def getP(self) -> java.math.BigInteger: ...
    def getQ(self) -> java.math.BigInteger: ...
    def getX(self) -> java.math.BigInteger: ...

class DSAPublicKeySpec(KeySpec):
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger, bigInteger3: java.math.BigInteger, bigInteger4: java.math.BigInteger): ...
    def getG(self) -> java.math.BigInteger: ...
    def getP(self) -> java.math.BigInteger: ...
    def getQ(self) -> java.math.BigInteger: ...
    def getY(self) -> java.math.BigInteger: ...

class ECFieldF2m(ECField):
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, int: int, intArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, int: int, bigInteger: java.math.BigInteger): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getFieldSize(self) -> int: ...
    def getM(self) -> int: ...
    def getMidTermsOfReductionPolynomial(self) -> typing.List[int]: ...
    def getReductionPolynomial(self) -> java.math.BigInteger: ...
    def hashCode(self) -> int: ...

class ECFieldFp(ECField):
    def __init__(self, bigInteger: java.math.BigInteger): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getFieldSize(self) -> int: ...
    def getP(self) -> java.math.BigInteger: ...
    def hashCode(self) -> int: ...

class ECParameterSpec(AlgorithmParameterSpec):
    def __init__(self, ellipticCurve: EllipticCurve, eCPoint: ECPoint, bigInteger: java.math.BigInteger, int: int): ...
    def getCofactor(self) -> int: ...
    def getCurve(self) -> EllipticCurve: ...
    def getGenerator(self) -> ECPoint: ...
    def getOrder(self) -> java.math.BigInteger: ...

class ECPrivateKeySpec(KeySpec):
    def __init__(self, bigInteger: java.math.BigInteger, eCParameterSpec: ECParameterSpec): ...
    def getParams(self) -> ECParameterSpec: ...
    def getS(self) -> java.math.BigInteger: ...

class ECPublicKeySpec(KeySpec):
    def __init__(self, eCPoint: ECPoint, eCParameterSpec: ECParameterSpec): ...
    def getParams(self) -> ECParameterSpec: ...
    def getW(self) -> ECPoint: ...

class EncodedKeySpec(KeySpec):
    def __init__(self, byteArray: typing.List[int]): ...
    def getAlgorithm(self) -> str: ...
    def getEncoded(self) -> typing.List[int]: ...
    def getFormat(self) -> str: ...

class MGF1ParameterSpec(AlgorithmParameterSpec):
    SHA1: typing.ClassVar['MGF1ParameterSpec'] = ...
    SHA224: typing.ClassVar['MGF1ParameterSpec'] = ...
    SHA256: typing.ClassVar['MGF1ParameterSpec'] = ...
    SHA384: typing.ClassVar['MGF1ParameterSpec'] = ...
    SHA512: typing.ClassVar['MGF1ParameterSpec'] = ...
    SHA512_224: typing.ClassVar['MGF1ParameterSpec'] = ...
    SHA512_256: typing.ClassVar['MGF1ParameterSpec'] = ...
    def __init__(self, string: str): ...
    def getDigestAlgorithm(self) -> str: ...

class NamedParameterSpec(AlgorithmParameterSpec):
    X25519: typing.ClassVar['NamedParameterSpec'] = ...
    X448: typing.ClassVar['NamedParameterSpec'] = ...
    def __init__(self, string: str): ...
    def getName(self) -> str: ...

class PSSParameterSpec(AlgorithmParameterSpec):
    TRAILER_FIELD_BC: typing.ClassVar[int] = ...
    DEFAULT: typing.ClassVar['PSSParameterSpec'] = ...
    @typing.overload
    def __init__(self, int: int): ...
    @typing.overload
    def __init__(self, string: str, string2: str, algorithmParameterSpec: AlgorithmParameterSpec, int: int, int2: int): ...
    def getDigestAlgorithm(self) -> str: ...
    def getMGFAlgorithm(self) -> str: ...
    def getMGFParameters(self) -> AlgorithmParameterSpec: ...
    def getSaltLength(self) -> int: ...
    def getTrailerField(self) -> int: ...
    def toString(self) -> str: ...

class RSAKeyGenParameterSpec(AlgorithmParameterSpec):
    F0: typing.ClassVar[java.math.BigInteger] = ...
    F4: typing.ClassVar[java.math.BigInteger] = ...
    @typing.overload
    def __init__(self, int: int, bigInteger: java.math.BigInteger): ...
    @typing.overload
    def __init__(self, int: int, bigInteger: java.math.BigInteger, algorithmParameterSpec: AlgorithmParameterSpec): ...
    def getKeyParams(self) -> AlgorithmParameterSpec: ...
    def getKeysize(self) -> int: ...
    def getPublicExponent(self) -> java.math.BigInteger: ...

class RSAPrivateKeySpec(KeySpec):
    @typing.overload
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger): ...
    @typing.overload
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger, algorithmParameterSpec: AlgorithmParameterSpec): ...
    def getModulus(self) -> java.math.BigInteger: ...
    def getParams(self) -> AlgorithmParameterSpec: ...
    def getPrivateExponent(self) -> java.math.BigInteger: ...

class RSAPublicKeySpec(KeySpec):
    @typing.overload
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger): ...
    @typing.overload
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger, algorithmParameterSpec: AlgorithmParameterSpec): ...
    def getModulus(self) -> java.math.BigInteger: ...
    def getParams(self) -> AlgorithmParameterSpec: ...
    def getPublicExponent(self) -> java.math.BigInteger: ...

class XECPrivateKeySpec(KeySpec):
    def __init__(self, algorithmParameterSpec: AlgorithmParameterSpec, byteArray: typing.List[int]): ...
    def getParams(self) -> AlgorithmParameterSpec: ...
    def getScalar(self) -> typing.List[int]: ...

class XECPublicKeySpec(KeySpec):
    def __init__(self, algorithmParameterSpec: AlgorithmParameterSpec, bigInteger: java.math.BigInteger): ...
    def getParams(self) -> AlgorithmParameterSpec: ...
    def getU(self) -> java.math.BigInteger: ...

class ECGenParameterSpec(NamedParameterSpec):
    def __init__(self, string: str): ...

class PKCS8EncodedKeySpec(EncodedKeySpec):
    @typing.overload
    def __init__(self, byteArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[int], string: str): ...
    def getEncoded(self) -> typing.List[int]: ...
    def getFormat(self) -> str: ...

class RSAMultiPrimePrivateCrtKeySpec(RSAPrivateKeySpec):
    @typing.overload
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger, bigInteger3: java.math.BigInteger, bigInteger4: java.math.BigInteger, bigInteger5: java.math.BigInteger, bigInteger6: java.math.BigInteger, bigInteger7: java.math.BigInteger, bigInteger8: java.math.BigInteger, rSAOtherPrimeInfoArray: typing.List[RSAOtherPrimeInfo]): ...
    @typing.overload
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger, bigInteger3: java.math.BigInteger, bigInteger4: java.math.BigInteger, bigInteger5: java.math.BigInteger, bigInteger6: java.math.BigInteger, bigInteger7: java.math.BigInteger, bigInteger8: java.math.BigInteger, rSAOtherPrimeInfoArray: typing.List[RSAOtherPrimeInfo], algorithmParameterSpec: AlgorithmParameterSpec): ...
    def getCrtCoefficient(self) -> java.math.BigInteger: ...
    def getOtherPrimeInfo(self) -> typing.List[RSAOtherPrimeInfo]: ...
    def getPrimeExponentP(self) -> java.math.BigInteger: ...
    def getPrimeExponentQ(self) -> java.math.BigInteger: ...
    def getPrimeP(self) -> java.math.BigInteger: ...
    def getPrimeQ(self) -> java.math.BigInteger: ...
    def getPublicExponent(self) -> java.math.BigInteger: ...

class RSAPrivateCrtKeySpec(RSAPrivateKeySpec):
    @typing.overload
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger, bigInteger3: java.math.BigInteger, bigInteger4: java.math.BigInteger, bigInteger5: java.math.BigInteger, bigInteger6: java.math.BigInteger, bigInteger7: java.math.BigInteger, bigInteger8: java.math.BigInteger): ...
    @typing.overload
    def __init__(self, bigInteger: java.math.BigInteger, bigInteger2: java.math.BigInteger, bigInteger3: java.math.BigInteger, bigInteger4: java.math.BigInteger, bigInteger5: java.math.BigInteger, bigInteger6: java.math.BigInteger, bigInteger7: java.math.BigInteger, bigInteger8: java.math.BigInteger, algorithmParameterSpec: AlgorithmParameterSpec): ...
    def getCrtCoefficient(self) -> java.math.BigInteger: ...
    def getPrimeExponentP(self) -> java.math.BigInteger: ...
    def getPrimeExponentQ(self) -> java.math.BigInteger: ...
    def getPrimeP(self) -> java.math.BigInteger: ...
    def getPrimeQ(self) -> java.math.BigInteger: ...
    def getPublicExponent(self) -> java.math.BigInteger: ...

class X509EncodedKeySpec(EncodedKeySpec):
    @typing.overload
    def __init__(self, byteArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[int], string: str): ...
    def getEncoded(self) -> typing.List[int]: ...
    def getFormat(self) -> str: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.security.spec")``.

    AlgorithmParameterSpec: typing.Type[AlgorithmParameterSpec]
    DSAGenParameterSpec: typing.Type[DSAGenParameterSpec]
    DSAParameterSpec: typing.Type[DSAParameterSpec]
    DSAPrivateKeySpec: typing.Type[DSAPrivateKeySpec]
    DSAPublicKeySpec: typing.Type[DSAPublicKeySpec]
    ECField: typing.Type[ECField]
    ECFieldF2m: typing.Type[ECFieldF2m]
    ECFieldFp: typing.Type[ECFieldFp]
    ECGenParameterSpec: typing.Type[ECGenParameterSpec]
    ECParameterSpec: typing.Type[ECParameterSpec]
    ECPoint: typing.Type[ECPoint]
    ECPrivateKeySpec: typing.Type[ECPrivateKeySpec]
    ECPublicKeySpec: typing.Type[ECPublicKeySpec]
    EllipticCurve: typing.Type[EllipticCurve]
    EncodedKeySpec: typing.Type[EncodedKeySpec]
    InvalidKeySpecException: typing.Type[InvalidKeySpecException]
    InvalidParameterSpecException: typing.Type[InvalidParameterSpecException]
    KeySpec: typing.Type[KeySpec]
    MGF1ParameterSpec: typing.Type[MGF1ParameterSpec]
    NamedParameterSpec: typing.Type[NamedParameterSpec]
    PKCS8EncodedKeySpec: typing.Type[PKCS8EncodedKeySpec]
    PSSParameterSpec: typing.Type[PSSParameterSpec]
    RSAKeyGenParameterSpec: typing.Type[RSAKeyGenParameterSpec]
    RSAMultiPrimePrivateCrtKeySpec: typing.Type[RSAMultiPrimePrivateCrtKeySpec]
    RSAOtherPrimeInfo: typing.Type[RSAOtherPrimeInfo]
    RSAPrivateCrtKeySpec: typing.Type[RSAPrivateCrtKeySpec]
    RSAPrivateKeySpec: typing.Type[RSAPrivateKeySpec]
    RSAPublicKeySpec: typing.Type[RSAPublicKeySpec]
    X509EncodedKeySpec: typing.Type[X509EncodedKeySpec]
    XECPrivateKeySpec: typing.Type[XECPrivateKeySpec]
    XECPublicKeySpec: typing.Type[XECPublicKeySpec]



import io.circe
import java.lang
import org.ergoplatform
import org.ergoplatform.validation
import scala
import scala.collection.immutable
import scala.util
import sigmastate
import sigmastate.interpreter
import special.collection
import special.sigma
import typing



_ErgoWalletSerializer__T = typing.TypeVar('_ErgoWalletSerializer__T')  # <T>
class ErgoWalletSerializer(typing.Generic[_ErgoWalletSerializer__T]):
    @staticmethod
    def $init$($this: 'ErgoWalletSerializer') -> None: ...
    def parseBytes(self, bytes: typing.List[int]) -> _ErgoWalletSerializer__T: ...
    def parseBytesTry(self, bytes: typing.List[int]) -> scala.util.Try[_ErgoWalletSerializer__T]: ...
    def toBytes(self, obj: _ErgoWalletSerializer__T) -> typing.List[int]: ...

class JsonCodecsWrapper:
    @staticmethod
    def adDigestDecoder() -> io.circe.Decoder[typing.List[int]]: ...
    @staticmethod
    def adDigestEncoder() -> io.circe.Encoder[typing.List[int]]: ...
    @staticmethod
    def adKeyDecoder() -> io.circe.Decoder[typing.List[int]]: ...
    @staticmethod
    def adKeyEncoder() -> io.circe.Encoder[typing.List[int]]: ...
    @staticmethod
    def anyValueDecoder() -> io.circe.Decoder[special.sigma.AnyValue]: ...
    @staticmethod
    def anyValueEncoder() -> io.circe.Encoder[special.sigma.AnyValue]: ...
    @staticmethod
    def arrayBytesDecoder() -> io.circe.Decoder[typing.List[int]]: ...
    @staticmethod
    def arrayBytesEncoder() -> io.circe.Encoder[typing.List[int]]: ...
    @staticmethod
    def assetDecoder() -> io.circe.Decoder[scala.Tuple2[typing.List[int], typing.Any]]: ...
    @staticmethod
    def assetEncoder() -> io.circe.Encoder[scala.Tuple2[typing.List[int], typing.Any]]: ...
    @staticmethod
    def avlTreeDataDecoder() -> io.circe.Decoder[sigmastate.AvlTreeData]: ...
    @staticmethod
    def avlTreeDataEncoder() -> io.circe.Encoder[sigmastate.AvlTreeData]: ...
    @staticmethod
    def collBytesDecoder() -> io.circe.Decoder[special.collection.Coll[typing.Any]]: ...
    @staticmethod
    def collBytesEncoder() -> io.circe.Encoder[special.collection.Coll[typing.Any]]: ...
    @staticmethod
    def contextExtensionDecoder() -> io.circe.Decoder[sigmastate.interpreter.ContextExtension]: ...
    @staticmethod
    def contextExtensionEncoder() -> io.circe.Encoder[sigmastate.interpreter.ContextExtension]: ...
    @staticmethod
    def dataInputDecoder() -> io.circe.Decoder[org.ergoplatform.DataInput]: ...
    @staticmethod
    def dataInputEncoder() -> io.circe.Encoder[org.ergoplatform.DataInput]: ...
    _decodeErgoTree__T = typing.TypeVar('_decodeErgoTree__T')  # <T>
    @staticmethod
    def decodeErgoTree(transform: scala.Function1[sigmastate.Values.ErgoTree, _decodeErgoTree__T]) -> io.circe.Decoder[_decodeErgoTree__T]: ...
    _decodeEvaluatedValue__T = typing.TypeVar('_decodeEvaluatedValue__T')  # <T>
    @staticmethod
    def decodeEvaluatedValue(transform: scala.Function1[sigmastate.Values.EvaluatedValue[sigmastate.SType], _decodeEvaluatedValue__T]) -> io.circe.Decoder[_decodeEvaluatedValue__T]: ...
    @staticmethod
    def digest32Decoder() -> io.circe.Decoder[typing.List[int]]: ...
    @staticmethod
    def digest32Encoder() -> io.circe.Encoder[typing.List[int]]: ...
    @staticmethod
    def ergoBoxDecoder() -> io.circe.Decoder[org.ergoplatform.ErgoBox]: ...
    @staticmethod
    def ergoBoxEncoder() -> io.circe.Encoder[org.ergoplatform.ErgoBox]: ...
    @staticmethod
    def ergoLikeContextDecoder() -> io.circe.Decoder[org.ergoplatform.ErgoLikeContext]: ...
    @staticmethod
    def ergoLikeContextEncoder() -> io.circe.Encoder[org.ergoplatform.ErgoLikeContext]: ...
    @staticmethod
    def ergoLikeTransactionDecoder() -> io.circe.Decoder[org.ergoplatform.ErgoLikeTransaction]: ...
    @staticmethod
    def ergoLikeTransactionEncoder() -> io.circe.Encoder[org.ergoplatform.ErgoLikeTransaction]: ...
    @staticmethod
    def ergoLikeTransactionTemplateDecoder() -> io.circe.Decoder[org.ergoplatform.ErgoLikeTransactionTemplate[org.ergoplatform.UnsignedInput]]: ...
    _ergoLikeTransactionTemplateEncoder__T = typing.TypeVar('_ergoLikeTransactionTemplateEncoder__T', bound=org.ergoplatform.UnsignedInput)  # <T>
    @staticmethod
    def ergoLikeTransactionTemplateEncoder() -> io.circe.Encoder[org.ergoplatform.ErgoLikeTransactionTemplate[_ergoLikeTransactionTemplateEncoder__T]]: ...
    @staticmethod
    def ergoTreeDecoder() -> io.circe.Decoder[sigmastate.Values.ErgoTree]: ...
    @staticmethod
    def ergoTreeEncoder() -> io.circe.Encoder[sigmastate.Values.ErgoTree]: ...
    @staticmethod
    def evaluatedValueDecoder() -> io.circe.Decoder[sigmastate.Values.EvaluatedValue[sigmastate.SType]]: ...
    @staticmethod
    def evaluatedValueEncoder() -> io.circe.Encoder[sigmastate.Values.EvaluatedValue[sigmastate.SType]]: ...
    _fromOption__T = typing.TypeVar('_fromOption__T')  # <T>
    @staticmethod
    def fromOption(maybeResult: scala.Option[_fromOption__T], cursor: io.circe.ACursor) -> scala.util.Either[io.circe.DecodingFailure, _fromOption__T]: ...
    _fromThrows__T = typing.TypeVar('_fromThrows__T')  # <T>
    @staticmethod
    def fromThrows(throwsBlock: scala.Function0[_fromThrows__T], cursor: io.circe.ACursor) -> scala.util.Either[io.circe.DecodingFailure, _fromThrows__T]: ...
    _fromTry__T = typing.TypeVar('_fromTry__T')  # <T>
    @staticmethod
    def fromTry(tryResult: scala.util.Try[_fromTry__T], cursor: io.circe.ACursor) -> scala.util.Either[io.circe.DecodingFailure, _fromTry__T]: ...
    @staticmethod
    def headerDecoder() -> io.circe.Decoder[special.sigma.Header]: ...
    @staticmethod
    def headerEncoder() -> io.circe.Encoder[special.sigma.Header]: ...
    @staticmethod
    def inputDecoder() -> io.circe.Decoder[org.ergoplatform.Input]: ...
    @staticmethod
    def inputEncoder() -> io.circe.Encoder[org.ergoplatform.Input]: ...
    @staticmethod
    def modifierIdDecoder() -> io.circe.Decoder[java.lang.String]: ...
    @staticmethod
    def modifierIdEncoder() -> io.circe.Encoder[java.lang.String]: ...
    @staticmethod
    def preHeaderDecoder() -> io.circe.Decoder[special.sigma.PreHeader]: ...
    @staticmethod
    def preHeaderEncoder() -> io.circe.Encoder[special.sigma.PreHeader]: ...
    @staticmethod
    def proverResultDecoder() -> io.circe.Decoder[sigmastate.interpreter.ProverResult]: ...
    @staticmethod
    def proverResultEncoder() -> io.circe.Encoder[sigmastate.interpreter.ProverResult]: ...
    @staticmethod
    def registerIdDecoder() -> io.circe.KeyDecoder[org.ergoplatform.ErgoBox.NonMandatoryRegisterId]: ...
    @staticmethod
    def registerIdEncoder() -> io.circe.KeyEncoder[org.ergoplatform.ErgoBox.NonMandatoryRegisterId]: ...
    _registersEncoder__T = typing.TypeVar('_registersEncoder__T', bound=sigmastate.Values.EvaluatedValue)  # <T>
    @staticmethod
    def registersEncoder() -> io.circe.Encoder[scala.collection.immutable.Map[org.ergoplatform.ErgoBox.NonMandatoryRegisterId, _registersEncoder__T]]: ...
    @staticmethod
    def sigmaBigIntDecoder() -> io.circe.Decoder[special.sigma.BigInt]: ...
    @staticmethod
    def sigmaBigIntEncoder() -> io.circe.Encoder[special.sigma.BigInt]: ...
    @staticmethod
    def sigmaValidationSettingsDecoder() -> io.circe.Decoder[org.ergoplatform.validation.SigmaValidationSettings]: ...
    @staticmethod
    def sigmaValidationSettingsEncoder() -> io.circe.Encoder[org.ergoplatform.validation.SigmaValidationSettings]: ...
    @staticmethod
    def transactionOutputsDecoder() -> io.circe.Decoder[scala.Tuple2[org.ergoplatform.ErgoBoxCandidate, scala.Option[typing.List[int]]]]: ...
    @staticmethod
    def unsignedErgoLikeTransactionDecoder() -> io.circe.Decoder[org.ergoplatform.UnsignedErgoLikeTransaction]: ...
    @staticmethod
    def unsignedErgoLikeTransactionEncoder() -> io.circe.Encoder[org.ergoplatform.UnsignedErgoLikeTransaction]: ...
    @staticmethod
    def unsignedInputDecoder() -> io.circe.Decoder[org.ergoplatform.UnsignedInput]: ...
    @staticmethod
    def unsignedInputEncoder() -> io.circe.Encoder[org.ergoplatform.UnsignedInput]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.wallet.serialization")``.

    ErgoWalletSerializer: typing.Type[ErgoWalletSerializer]
    JsonCodecsWrapper: typing.Type[JsonCodecsWrapper]



import java
import java.io
import java.lang
import java.net
import java.nio
import java.security.acl
import java.security.cert
import java.security.interfaces
import java.security.spec
import java.util
import java.util.function
import java.util.stream
import javax.crypto
import javax.security.auth
import javax.security.auth.callback
import javax.security.auth.login
import jpype.protocol
import typing



class AccessControlContext:
    @typing.overload
    def __init__(self, accessControlContext: 'AccessControlContext', domainCombiner: 'DomainCombiner'): ...
    @typing.overload
    def __init__(self, protectionDomainArray: typing.List['ProtectionDomain']): ...
    def checkPermission(self, permission: 'Permission') -> None: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getDomainCombiner(self) -> 'DomainCombiner': ...
    def hashCode(self) -> int: ...

class AccessControlException(java.lang.SecurityException):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, permission: 'Permission'): ...
    def getPermission(self) -> 'Permission': ...

class AccessController:
    @staticmethod
    def checkPermission(permission: 'Permission') -> None: ...
    _doPrivileged_0__T = typing.TypeVar('_doPrivileged_0__T')  # <T>
    _doPrivileged_1__T = typing.TypeVar('_doPrivileged_1__T')  # <T>
    _doPrivileged_2__T = typing.TypeVar('_doPrivileged_2__T')  # <T>
    _doPrivileged_3__T = typing.TypeVar('_doPrivileged_3__T')  # <T>
    _doPrivileged_4__T = typing.TypeVar('_doPrivileged_4__T')  # <T>
    _doPrivileged_5__T = typing.TypeVar('_doPrivileged_5__T')  # <T>
    @typing.overload
    @staticmethod
    def doPrivileged(privilegedAction: 'PrivilegedAction'[_doPrivileged_0__T], accessControlContext: AccessControlContext, permissionArray: typing.List['Permission']) -> _doPrivileged_0__T: ...
    @typing.overload
    @staticmethod
    def doPrivileged(privilegedExceptionAction: 'PrivilegedExceptionAction'[_doPrivileged_1__T], accessControlContext: AccessControlContext, permissionArray: typing.List['Permission']) -> _doPrivileged_1__T: ...
    @typing.overload
    @staticmethod
    def doPrivileged(privilegedAction: 'PrivilegedAction'[_doPrivileged_2__T]) -> _doPrivileged_2__T: ...
    @typing.overload
    @staticmethod
    def doPrivileged(privilegedAction: 'PrivilegedAction'[_doPrivileged_3__T], accessControlContext: AccessControlContext) -> _doPrivileged_3__T: ...
    @typing.overload
    @staticmethod
    def doPrivileged(privilegedExceptionAction: 'PrivilegedExceptionAction'[_doPrivileged_4__T]) -> _doPrivileged_4__T: ...
    @typing.overload
    @staticmethod
    def doPrivileged(privilegedExceptionAction: 'PrivilegedExceptionAction'[_doPrivileged_5__T], accessControlContext: AccessControlContext) -> _doPrivileged_5__T: ...
    _doPrivilegedWithCombiner_0__T = typing.TypeVar('_doPrivilegedWithCombiner_0__T')  # <T>
    _doPrivilegedWithCombiner_1__T = typing.TypeVar('_doPrivilegedWithCombiner_1__T')  # <T>
    _doPrivilegedWithCombiner_2__T = typing.TypeVar('_doPrivilegedWithCombiner_2__T')  # <T>
    _doPrivilegedWithCombiner_3__T = typing.TypeVar('_doPrivilegedWithCombiner_3__T')  # <T>
    @typing.overload
    @staticmethod
    def doPrivilegedWithCombiner(privilegedAction: 'PrivilegedAction'[_doPrivilegedWithCombiner_0__T]) -> _doPrivilegedWithCombiner_0__T: ...
    @typing.overload
    @staticmethod
    def doPrivilegedWithCombiner(privilegedAction: 'PrivilegedAction'[_doPrivilegedWithCombiner_1__T], accessControlContext: AccessControlContext, permissionArray: typing.List['Permission']) -> _doPrivilegedWithCombiner_1__T: ...
    @typing.overload
    @staticmethod
    def doPrivilegedWithCombiner(privilegedExceptionAction: 'PrivilegedExceptionAction'[_doPrivilegedWithCombiner_2__T]) -> _doPrivilegedWithCombiner_2__T: ...
    @typing.overload
    @staticmethod
    def doPrivilegedWithCombiner(privilegedExceptionAction: 'PrivilegedExceptionAction'[_doPrivilegedWithCombiner_3__T], accessControlContext: AccessControlContext, permissionArray: typing.List['Permission']) -> _doPrivilegedWithCombiner_3__T: ...
    @staticmethod
    def getContext() -> AccessControlContext: ...

class AlgorithmConstraints:
    @typing.overload
    def permits(self, set: java.util.Set['CryptoPrimitive'], string: str, algorithmParameters: 'AlgorithmParameters') -> bool: ...
    @typing.overload
    def permits(self, set: java.util.Set['CryptoPrimitive'], string: str, key: 'Key', algorithmParameters: 'AlgorithmParameters') -> bool: ...
    @typing.overload
    def permits(self, set: java.util.Set['CryptoPrimitive'], key: 'Key') -> bool: ...

class AlgorithmParameterGenerator:
    def generateParameters(self) -> 'AlgorithmParameters': ...
    def getAlgorithm(self) -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(string: str) -> 'AlgorithmParameterGenerator': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, string2: str) -> 'AlgorithmParameterGenerator': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, provider: 'Provider') -> 'AlgorithmParameterGenerator': ...
    def getProvider(self) -> 'Provider': ...
    @typing.overload
    def init(self, int: int) -> None: ...
    @typing.overload
    def init(self, int: int, secureRandom: 'SecureRandom') -> None: ...
    @typing.overload
    def init(self, algorithmParameterSpec: java.security.spec.AlgorithmParameterSpec) -> None: ...
    @typing.overload
    def init(self, algorithmParameterSpec: java.security.spec.AlgorithmParameterSpec, secureRandom: 'SecureRandom') -> None: ...

class AlgorithmParameterGeneratorSpi:
    def __init__(self): ...

class AlgorithmParameters:
    def getAlgorithm(self) -> str: ...
    @typing.overload
    def getEncoded(self) -> typing.List[int]: ...
    @typing.overload
    def getEncoded(self, string: str) -> typing.List[int]: ...
    @typing.overload
    @staticmethod
    def getInstance(string: str) -> 'AlgorithmParameters': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, string2: str) -> 'AlgorithmParameters': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, provider: 'Provider') -> 'AlgorithmParameters': ...
    _getParameterSpec__T = typing.TypeVar('_getParameterSpec__T', bound=java.security.spec.AlgorithmParameterSpec)  # <T>
    def getParameterSpec(self, class_: typing.Type[_getParameterSpec__T]) -> _getParameterSpec__T: ...
    def getProvider(self) -> 'Provider': ...
    @typing.overload
    def init(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def init(self, byteArray: typing.List[int], string: str) -> None: ...
    @typing.overload
    def init(self, algorithmParameterSpec: java.security.spec.AlgorithmParameterSpec) -> None: ...
    def toString(self) -> str: ...

class AlgorithmParametersSpi:
    def __init__(self): ...

class Certificate:
    def decode(self, inputStream: java.io.InputStream) -> None: ...
    def encode(self, outputStream: java.io.OutputStream) -> None: ...
    def getFormat(self) -> str: ...
    def getGuarantor(self) -> 'Principal': ...
    def getPrincipal(self) -> 'Principal': ...
    def getPublicKey(self) -> 'PublicKey': ...
    def toString(self, boolean: bool) -> str: ...

class CodeSigner(java.io.Serializable):
    def __init__(self, certPath: java.security.cert.CertPath, timestamp: 'Timestamp'): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getSignerCertPath(self) -> java.security.cert.CertPath: ...
    def getTimestamp(self) -> 'Timestamp': ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class CodeSource(java.io.Serializable):
    @typing.overload
    def __init__(self, uRL: java.net.URL, codeSignerArray: typing.List[CodeSigner]): ...
    @typing.overload
    def __init__(self, uRL: java.net.URL, certificateArray: typing.List[java.security.cert.Certificate]): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getCertificates(self) -> typing.List[java.security.cert.Certificate]: ...
    def getCodeSigners(self) -> typing.List[CodeSigner]: ...
    def getLocation(self) -> java.net.URL: ...
    def hashCode(self) -> int: ...
    def implies(self, codeSource: 'CodeSource') -> bool: ...
    def toString(self) -> str: ...

class CryptoPrimitive(java.lang.Enum['CryptoPrimitive']):
    MESSAGE_DIGEST: typing.ClassVar['CryptoPrimitive'] = ...
    SECURE_RANDOM: typing.ClassVar['CryptoPrimitive'] = ...
    BLOCK_CIPHER: typing.ClassVar['CryptoPrimitive'] = ...
    STREAM_CIPHER: typing.ClassVar['CryptoPrimitive'] = ...
    MAC: typing.ClassVar['CryptoPrimitive'] = ...
    KEY_WRAP: typing.ClassVar['CryptoPrimitive'] = ...
    PUBLIC_KEY_ENCRYPTION: typing.ClassVar['CryptoPrimitive'] = ...
    SIGNATURE: typing.ClassVar['CryptoPrimitive'] = ...
    KEY_ENCAPSULATION: typing.ClassVar['CryptoPrimitive'] = ...
    KEY_AGREEMENT: typing.ClassVar['CryptoPrimitive'] = ...
    _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
    @typing.overload
    @staticmethod
    def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
    @typing.overload
    @staticmethod
    def valueOf(string: str) -> 'CryptoPrimitive': ...
    @staticmethod
    def values() -> typing.List['CryptoPrimitive']: ...

class DigestInputStream(java.io.FilterInputStream):
    def __init__(self, inputStream: java.io.InputStream, messageDigest: 'MessageDigest'): ...
    def getMessageDigest(self) -> 'MessageDigest': ...
    def on(self, boolean: bool) -> None: ...
    @typing.overload
    def read(self, byteArray: typing.List[int]) -> int: ...
    @typing.overload
    def read(self) -> int: ...
    @typing.overload
    def read(self, byteArray: typing.List[int], int: int, int2: int) -> int: ...
    def setMessageDigest(self, messageDigest: 'MessageDigest') -> None: ...
    def toString(self) -> str: ...

class DigestOutputStream(java.io.FilterOutputStream):
    def __init__(self, outputStream: java.io.OutputStream, messageDigest: 'MessageDigest'): ...
    def getMessageDigest(self) -> 'MessageDigest': ...
    def on(self, boolean: bool) -> None: ...
    def setMessageDigest(self, messageDigest: 'MessageDigest') -> None: ...
    def toString(self) -> str: ...
    @typing.overload
    def write(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def write(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def write(self, int: int) -> None: ...

class DomainCombiner:
    def combine(self, protectionDomainArray: typing.List['ProtectionDomain'], protectionDomainArray2: typing.List['ProtectionDomain']) -> typing.List['ProtectionDomain']: ...

class GeneralSecurityException(java.lang.Exception):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class Guard:
    def checkGuard(self, object: typing.Any) -> None: ...

class GuardedObject(java.io.Serializable):
    def __init__(self, object: typing.Any, guard: Guard): ...
    def getObject(self) -> typing.Any: ...

class InvalidParameterException(java.lang.IllegalArgumentException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class Key(java.io.Serializable):
    serialVersionUID: typing.ClassVar[int] = ...
    def getAlgorithm(self) -> str: ...
    def getEncoded(self) -> typing.List[int]: ...
    def getFormat(self) -> str: ...

class KeyFactory:
    def generatePrivate(self, keySpec: java.security.spec.KeySpec) -> 'PrivateKey': ...
    def generatePublic(self, keySpec: java.security.spec.KeySpec) -> 'PublicKey': ...
    def getAlgorithm(self) -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(string: str) -> 'KeyFactory': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, string2: str) -> 'KeyFactory': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, provider: 'Provider') -> 'KeyFactory': ...
    _getKeySpec__T = typing.TypeVar('_getKeySpec__T', bound=java.security.spec.KeySpec)  # <T>
    def getKeySpec(self, key: Key, class_: typing.Type[_getKeySpec__T]) -> _getKeySpec__T: ...
    def getProvider(self) -> 'Provider': ...
    def translateKey(self, key: Key) -> Key: ...

class KeyFactorySpi:
    def __init__(self): ...

class KeyPair(java.io.Serializable):
    def __init__(self, publicKey: 'PublicKey', privateKey: 'PrivateKey'): ...
    def getPrivate(self) -> 'PrivateKey': ...
    def getPublic(self) -> 'PublicKey': ...

class KeyPairGeneratorSpi:
    def __init__(self): ...
    def generateKeyPair(self) -> KeyPair: ...
    @typing.overload
    def initialize(self, int: int, secureRandom: 'SecureRandom') -> None: ...
    @typing.overload
    def initialize(self, algorithmParameterSpec: java.security.spec.AlgorithmParameterSpec, secureRandom: 'SecureRandom') -> None: ...

class KeyRep(java.io.Serializable):
    def __init__(self, type: 'KeyRep.Type', string: str, string2: str, byteArray: typing.List[int]): ...
    class Type(java.lang.Enum['KeyRep.Type']):
        SECRET: typing.ClassVar['KeyRep.Type'] = ...
        PUBLIC: typing.ClassVar['KeyRep.Type'] = ...
        PRIVATE: typing.ClassVar['KeyRep.Type'] = ...
        _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'KeyRep.Type': ...
        @staticmethod
        def values() -> typing.List['KeyRep.Type']: ...

class KeyStoreSpi:
    def __init__(self): ...
    def engineAliases(self) -> java.util.Enumeration[str]: ...
    def engineContainsAlias(self, string: str) -> bool: ...
    def engineDeleteEntry(self, string: str) -> None: ...
    def engineEntryInstanceOf(self, string: str, class_: typing.Type['KeyStore.Entry']) -> bool: ...
    def engineGetCertificate(self, string: str) -> java.security.cert.Certificate: ...
    def engineGetCertificateAlias(self, certificate: java.security.cert.Certificate) -> str: ...
    def engineGetCertificateChain(self, string: str) -> typing.List[java.security.cert.Certificate]: ...
    def engineGetCreationDate(self, string: str) -> java.util.Date: ...
    def engineGetEntry(self, string: str, protectionParameter: 'KeyStore.ProtectionParameter') -> 'KeyStore.Entry': ...
    def engineGetKey(self, string: str, charArray: typing.List[str]) -> Key: ...
    def engineIsCertificateEntry(self, string: str) -> bool: ...
    def engineIsKeyEntry(self, string: str) -> bool: ...
    @typing.overload
    def engineLoad(self, inputStream: java.io.InputStream, charArray: typing.List[str]) -> None: ...
    @typing.overload
    def engineLoad(self, loadStoreParameter: 'KeyStore.LoadStoreParameter') -> None: ...
    def engineProbe(self, inputStream: java.io.InputStream) -> bool: ...
    def engineSetCertificateEntry(self, string: str, certificate: java.security.cert.Certificate) -> None: ...
    def engineSetEntry(self, string: str, entry: 'KeyStore.Entry', protectionParameter: 'KeyStore.ProtectionParameter') -> None: ...
    @typing.overload
    def engineSetKeyEntry(self, string: str, byteArray: typing.List[int], certificateArray: typing.List[java.security.cert.Certificate]) -> None: ...
    @typing.overload
    def engineSetKeyEntry(self, string: str, key: Key, charArray: typing.List[str], certificateArray: typing.List[java.security.cert.Certificate]) -> None: ...
    def engineSize(self) -> int: ...
    @typing.overload
    def engineStore(self, outputStream: java.io.OutputStream, charArray: typing.List[str]) -> None: ...
    @typing.overload
    def engineStore(self, loadStoreParameter: 'KeyStore.LoadStoreParameter') -> None: ...

class MessageDigestSpi:
    def __init__(self): ...
    def clone(self) -> typing.Any: ...

class PermissionCollection(java.io.Serializable):
    def __init__(self): ...
    def add(self, permission: 'Permission') -> None: ...
    def elements(self) -> java.util.Enumeration['Permission']: ...
    def elementsAsStream(self) -> java.util.stream.Stream['Permission']: ...
    def implies(self, permission: 'Permission') -> bool: ...
    def isReadOnly(self) -> bool: ...
    def setReadOnly(self) -> None: ...
    def toString(self) -> str: ...

class Policy:
    UNSUPPORTED_EMPTY_COLLECTION: typing.ClassVar[PermissionCollection] = ...
    def __init__(self): ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, parameters: 'Policy.Parameters') -> 'Policy': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, parameters: 'Policy.Parameters', string2: str) -> 'Policy': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, parameters: 'Policy.Parameters', provider: 'Provider') -> 'Policy': ...
    def getParameters(self) -> 'Policy.Parameters': ...
    @typing.overload
    def getPermissions(self, codeSource: CodeSource) -> PermissionCollection: ...
    @typing.overload
    def getPermissions(self, protectionDomain: 'ProtectionDomain') -> PermissionCollection: ...
    @staticmethod
    def getPolicy() -> 'Policy': ...
    def getProvider(self) -> 'Provider': ...
    def getType(self) -> str: ...
    def implies(self, protectionDomain: 'ProtectionDomain', permission: 'Permission') -> bool: ...
    def refresh(self) -> None: ...
    @staticmethod
    def setPolicy(policy: 'Policy') -> None: ...
    class Parameters: ...

class PolicySpi:
    def __init__(self): ...

class Principal:
    def equals(self, object: typing.Any) -> bool: ...
    def getName(self) -> str: ...
    def hashCode(self) -> int: ...
    def implies(self, subject: javax.security.auth.Subject) -> bool: ...
    def toString(self) -> str: ...

_PrivilegedAction__T = typing.TypeVar('_PrivilegedAction__T')  # <T>
class PrivilegedAction(typing.Generic[_PrivilegedAction__T]):
    def run(self) -> _PrivilegedAction__T: ...

class PrivilegedActionException(java.lang.Exception):
    def __init__(self, exception: java.lang.Exception): ...
    def getCause(self) -> java.lang.Throwable: ...
    def getException(self) -> java.lang.Exception: ...
    def toString(self) -> str: ...

_PrivilegedExceptionAction__T = typing.TypeVar('_PrivilegedExceptionAction__T')  # <T>
class PrivilegedExceptionAction(typing.Generic[_PrivilegedExceptionAction__T]):
    def run(self) -> _PrivilegedExceptionAction__T: ...

class ProtectionDomain:
    @typing.overload
    def __init__(self, codeSource: CodeSource, permissionCollection: PermissionCollection): ...
    @typing.overload
    def __init__(self, codeSource: CodeSource, permissionCollection: PermissionCollection, classLoader: java.lang.ClassLoader, principalArray: typing.List[Principal]): ...
    def getClassLoader(self) -> java.lang.ClassLoader: ...
    def getCodeSource(self) -> CodeSource: ...
    def getPermissions(self) -> PermissionCollection: ...
    def getPrincipals(self) -> typing.List[Principal]: ...
    def implies(self, permission: 'Permission') -> bool: ...
    def staticPermissionsOnly(self) -> bool: ...
    def toString(self) -> str: ...

class Provider(java.util.Properties):
    def clear(self) -> None: ...
    def compute(self, object: typing.Any, biFunction: typing.Union[java.util.function.BiFunction[typing.Any, typing.Any, typing.Any], typing.Callable[[typing.Any, typing.Any], typing.Any]]) -> typing.Any: ...
    def computeIfAbsent(self, object: typing.Any, function: typing.Union[java.util.function.Function[typing.Any, typing.Any], typing.Callable[[typing.Any], typing.Any]]) -> typing.Any: ...
    def computeIfPresent(self, object: typing.Any, biFunction: typing.Union[java.util.function.BiFunction[typing.Any, typing.Any, typing.Any], typing.Callable[[typing.Any, typing.Any], typing.Any]]) -> typing.Any: ...
    def configure(self, string: str) -> 'Provider': ...
    def elements(self) -> java.util.Enumeration[typing.Any]: ...
    def entrySet(self) -> java.util.Set[java.util.Map.Entry[typing.Any, typing.Any]]: ...
    def forEach(self, biConsumer: typing.Union[java.util.function.BiConsumer[typing.Any, typing.Any], typing.Callable[[typing.Any, typing.Any], None]]) -> None: ...
    def get(self, object: typing.Any) -> typing.Any: ...
    def getInfo(self) -> str: ...
    def getName(self) -> str: ...
    def getOrDefault(self, object: typing.Any, object2: typing.Any) -> typing.Any: ...
    @typing.overload
    def getProperty(self, string: str) -> str: ...
    @typing.overload
    def getProperty(self, string: str, string2: str) -> str: ...
    def getService(self, string: str, string2: str) -> 'Provider.Service': ...
    def getServices(self) -> java.util.Set['Provider.Service']: ...
    def getVersion(self) -> float: ...
    def getVersionStr(self) -> str: ...
    def isConfigured(self) -> bool: ...
    def keySet(self) -> java.util.Set[typing.Any]: ...
    def keys(self) -> java.util.Enumeration[typing.Any]: ...
    @typing.overload
    def load(self, inputStream: java.io.InputStream) -> None: ...
    @typing.overload
    def load(self, reader: java.io.Reader) -> None: ...
    def merge(self, object: typing.Any, object2: typing.Any, biFunction: typing.Union[java.util.function.BiFunction[typing.Any, typing.Any, typing.Any], typing.Callable[[typing.Any, typing.Any], typing.Any]]) -> typing.Any: ...
    def put(self, object: typing.Any, object2: typing.Any) -> typing.Any: ...
    def putAll(self, map: typing.Union[java.util.Map[typing.Any, typing.Any], typing.Mapping[typing.Any, typing.Any]]) -> None: ...
    def putIfAbsent(self, object: typing.Any, object2: typing.Any) -> typing.Any: ...
    @typing.overload
    def remove(self, object: typing.Any, object2: typing.Any) -> bool: ...
    @typing.overload
    def remove(self, object: typing.Any) -> typing.Any: ...
    @typing.overload
    def replace(self, object: typing.Any, object2: typing.Any, object3: typing.Any) -> bool: ...
    @typing.overload
    def replace(self, object: typing.Any, object2: typing.Any) -> typing.Any: ...
    def replaceAll(self, biFunction: typing.Union[java.util.function.BiFunction[typing.Any, typing.Any, typing.Any], typing.Callable[[typing.Any, typing.Any], typing.Any]]) -> None: ...
    def toString(self) -> str: ...
    def values(self) -> java.util.Collection[typing.Any]: ...
    class Service:
        def __init__(self, provider: 'Provider', string: str, string2: str, string3: str, list: java.util.List[str], map: typing.Union[java.util.Map[str, str], typing.Mapping[str, str]]): ...
        def getAlgorithm(self) -> str: ...
        def getAttribute(self, string: str) -> str: ...
        def getClassName(self) -> str: ...
        def getProvider(self) -> 'Provider': ...
        def getType(self) -> str: ...
        def newInstance(self, object: typing.Any) -> typing.Any: ...
        def supportsParameter(self, object: typing.Any) -> bool: ...
        def toString(self) -> str: ...

class ProviderException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class SecureClassLoader(java.lang.ClassLoader): ...

class SecureRandom(java.util.Random):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, byteArray: typing.List[int]): ...
    def generateSeed(self, int: int) -> typing.List[int]: ...
    def getAlgorithm(self) -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(string: str) -> 'SecureRandom': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, string2: str) -> 'SecureRandom': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, provider: Provider) -> 'SecureRandom': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, secureRandomParameters: 'SecureRandomParameters') -> 'SecureRandom': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, secureRandomParameters: 'SecureRandomParameters', string2: str) -> 'SecureRandom': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, secureRandomParameters: 'SecureRandomParameters', provider: Provider) -> 'SecureRandom': ...
    @staticmethod
    def getInstanceStrong() -> 'SecureRandom': ...
    def getParameters(self) -> 'SecureRandomParameters': ...
    def getProvider(self) -> Provider: ...
    @staticmethod
    def getSeed(int: int) -> typing.List[int]: ...
    @typing.overload
    def nextBytes(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def nextBytes(self, byteArray: typing.List[int], secureRandomParameters: 'SecureRandomParameters') -> None: ...
    @typing.overload
    def reseed(self) -> None: ...
    @typing.overload
    def reseed(self, secureRandomParameters: 'SecureRandomParameters') -> None: ...
    @typing.overload
    def setSeed(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def setSeed(self, long: int) -> None: ...
    def toString(self) -> str: ...

class SecureRandomParameters: ...

class SecureRandomSpi(java.io.Serializable):
    def __init__(self): ...
    def toString(self) -> str: ...

class Security:
    @staticmethod
    def addProvider(provider: Provider) -> int: ...
    @staticmethod
    def getAlgorithmProperty(string: str, string2: str) -> str: ...
    @staticmethod
    def getAlgorithms(string: str) -> java.util.Set[str]: ...
    @staticmethod
    def getProperty(string: str) -> str: ...
    @staticmethod
    def getProvider(string: str) -> Provider: ...
    @typing.overload
    @staticmethod
    def getProviders() -> typing.List[Provider]: ...
    @typing.overload
    @staticmethod
    def getProviders(string: str) -> typing.List[Provider]: ...
    @typing.overload
    @staticmethod
    def getProviders(map: typing.Union[java.util.Map[str, str], typing.Mapping[str, str]]) -> typing.List[Provider]: ...
    @staticmethod
    def insertProviderAt(provider: Provider, int: int) -> int: ...
    @staticmethod
    def removeProvider(string: str) -> None: ...
    @staticmethod
    def setProperty(string: str, string2: str) -> None: ...

class SignatureSpi:
    def __init__(self): ...
    def clone(self) -> typing.Any: ...

class SignedObject(java.io.Serializable):
    def __init__(self, serializable: java.io.Serializable, privateKey: 'PrivateKey', signature: 'Signature'): ...
    def getAlgorithm(self) -> str: ...
    def getObject(self) -> typing.Any: ...
    def getSignature(self) -> typing.List[int]: ...
    def verify(self, publicKey: 'PublicKey', signature: 'Signature') -> bool: ...

class Timestamp(java.io.Serializable):
    def __init__(self, date: java.util.Date, certPath: java.security.cert.CertPath): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getSignerCertPath(self) -> java.security.cert.CertPath: ...
    def getTimestamp(self) -> java.util.Date: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...

class AuthProvider(Provider):
    def login(self, subject: javax.security.auth.Subject, callbackHandler: javax.security.auth.callback.CallbackHandler) -> None: ...
    def logout(self) -> None: ...
    def setCallbackHandler(self, callbackHandler: javax.security.auth.callback.CallbackHandler) -> None: ...

class DigestException(GeneralSecurityException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class DrbgParameters:
    @staticmethod
    def instantiation(int: int, capability: 'DrbgParameters.Capability', byteArray: typing.List[int]) -> 'DrbgParameters.Instantiation': ...
    @staticmethod
    def nextBytes(int: int, boolean: bool, byteArray: typing.List[int]) -> 'DrbgParameters.NextBytes': ...
    @staticmethod
    def reseed(boolean: bool, byteArray: typing.List[int]) -> 'DrbgParameters.Reseed': ...
    class Capability(java.lang.Enum['DrbgParameters.Capability']):
        PR_AND_RESEED: typing.ClassVar['DrbgParameters.Capability'] = ...
        RESEED_ONLY: typing.ClassVar['DrbgParameters.Capability'] = ...
        NONE: typing.ClassVar['DrbgParameters.Capability'] = ...
        def supportsPredictionResistance(self) -> bool: ...
        def supportsReseeding(self) -> bool: ...
        def toString(self) -> str: ...
        _valueOf_0__T = typing.TypeVar('_valueOf_0__T', bound=java.lang.Enum)  # <T>
        @typing.overload
        @staticmethod
        def valueOf(class_: typing.Type[_valueOf_0__T], string: str) -> _valueOf_0__T: ...
        @typing.overload
        @staticmethod
        def valueOf(string: str) -> 'DrbgParameters.Capability': ...
        @staticmethod
        def values() -> typing.List['DrbgParameters.Capability']: ...
    class Instantiation(SecureRandomParameters):
        def getCapability(self) -> 'DrbgParameters.Capability': ...
        def getPersonalizationString(self) -> typing.List[int]: ...
        def getStrength(self) -> int: ...
        def toString(self) -> str: ...
    class NextBytes(SecureRandomParameters):
        def getAdditionalInput(self) -> typing.List[int]: ...
        def getPredictionResistance(self) -> bool: ...
        def getStrength(self) -> int: ...
    class Reseed(SecureRandomParameters):
        def getAdditionalInput(self) -> typing.List[int]: ...
        def getPredictionResistance(self) -> bool: ...

class Identity(Principal, java.io.Serializable):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, identityScope: 'IdentityScope'): ...
    def addCertificate(self, certificate: Certificate) -> None: ...
    def certificates(self) -> typing.List[Certificate]: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getInfo(self) -> str: ...
    def getName(self) -> str: ...
    def getPublicKey(self) -> 'PublicKey': ...
    def getScope(self) -> 'IdentityScope': ...
    def hashCode(self) -> int: ...
    def removeCertificate(self, certificate: Certificate) -> None: ...
    def setInfo(self, string: str) -> None: ...
    def setPublicKey(self, publicKey: 'PublicKey') -> None: ...
    @typing.overload
    def toString(self) -> str: ...
    @typing.overload
    def toString(self, boolean: bool) -> str: ...

class InvalidAlgorithmParameterException(GeneralSecurityException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class KeyException(GeneralSecurityException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class KeyPairGenerator(KeyPairGeneratorSpi):
    def genKeyPair(self) -> KeyPair: ...
    def generateKeyPair(self) -> KeyPair: ...
    def getAlgorithm(self) -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(string: str) -> 'KeyPairGenerator': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, string2: str) -> 'KeyPairGenerator': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, provider: Provider) -> 'KeyPairGenerator': ...
    def getProvider(self) -> Provider: ...
    @typing.overload
    def initialize(self, int: int) -> None: ...
    @typing.overload
    def initialize(self, int: int, secureRandom: SecureRandom) -> None: ...
    @typing.overload
    def initialize(self, algorithmParameterSpec: java.security.spec.AlgorithmParameterSpec) -> None: ...
    @typing.overload
    def initialize(self, algorithmParameterSpec: java.security.spec.AlgorithmParameterSpec, secureRandom: SecureRandom) -> None: ...

class KeyStoreException(GeneralSecurityException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class MessageDigest(MessageDigestSpi):
    def clone(self) -> typing.Any: ...
    @typing.overload
    def digest(self) -> typing.List[int]: ...
    @typing.overload
    def digest(self, byteArray: typing.List[int]) -> typing.List[int]: ...
    @typing.overload
    def digest(self, byteArray: typing.List[int], int: int, int2: int) -> int: ...
    def getAlgorithm(self) -> str: ...
    def getDigestLength(self) -> int: ...
    @typing.overload
    @staticmethod
    def getInstance(string: str) -> 'MessageDigest': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, string2: str) -> 'MessageDigest': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, provider: Provider) -> 'MessageDigest': ...
    def getProvider(self) -> Provider: ...
    @staticmethod
    def isEqual(byteArray: typing.List[int], byteArray2: typing.List[int]) -> bool: ...
    def reset(self) -> None: ...
    def toString(self) -> str: ...
    @typing.overload
    def update(self, byteBuffer: java.nio.ByteBuffer) -> None: ...
    @typing.overload
    def update(self, byte: int) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...

class NoSuchAlgorithmException(GeneralSecurityException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class NoSuchProviderException(GeneralSecurityException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class Permission(Guard, java.io.Serializable):
    def __init__(self, string: str): ...
    def checkGuard(self, object: typing.Any) -> None: ...
    def equals(self, object: typing.Any) -> bool: ...
    def getActions(self) -> str: ...
    def getName(self) -> str: ...
    def hashCode(self) -> int: ...
    def implies(self, permission: 'Permission') -> bool: ...
    def newPermissionCollection(self) -> PermissionCollection: ...
    def toString(self) -> str: ...

class Permissions(PermissionCollection, java.io.Serializable):
    def __init__(self): ...
    def add(self, permission: Permission) -> None: ...
    def elements(self) -> java.util.Enumeration[Permission]: ...
    def implies(self, permission: Permission) -> bool: ...

class PrivateKey(Key, javax.security.auth.Destroyable):
    serialVersionUID: typing.ClassVar[int] = ...

class PublicKey(Key):
    serialVersionUID: typing.ClassVar[int] = ...

class Signature(SignatureSpi):
    def clone(self) -> typing.Any: ...
    def getAlgorithm(self) -> str: ...
    @typing.overload
    @staticmethod
    def getInstance(string: str) -> 'Signature': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, string2: str) -> 'Signature': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, provider: Provider) -> 'Signature': ...
    def getParameter(self, string: str) -> typing.Any: ...
    def getParameters(self) -> AlgorithmParameters: ...
    def getProvider(self) -> Provider: ...
    @typing.overload
    def initSign(self, privateKey: PrivateKey) -> None: ...
    @typing.overload
    def initSign(self, privateKey: PrivateKey, secureRandom: SecureRandom) -> None: ...
    @typing.overload
    def initVerify(self, publicKey: PublicKey) -> None: ...
    @typing.overload
    def initVerify(self, certificate: java.security.cert.Certificate) -> None: ...
    @typing.overload
    def setParameter(self, string: str, object: typing.Any) -> None: ...
    @typing.overload
    def setParameter(self, algorithmParameterSpec: java.security.spec.AlgorithmParameterSpec) -> None: ...
    @typing.overload
    def sign(self) -> typing.List[int]: ...
    @typing.overload
    def sign(self, byteArray: typing.List[int], int: int, int2: int) -> int: ...
    def toString(self) -> str: ...
    @typing.overload
    def update(self, byte: int) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int]) -> None: ...
    @typing.overload
    def update(self, byteArray: typing.List[int], int: int, int2: int) -> None: ...
    @typing.overload
    def update(self, byteBuffer: java.nio.ByteBuffer) -> None: ...
    @typing.overload
    def verify(self, byteArray: typing.List[int]) -> bool: ...
    @typing.overload
    def verify(self, byteArray: typing.List[int], int: int, int2: int) -> bool: ...

class SignatureException(GeneralSecurityException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class URIParameter(Policy.Parameters, javax.security.auth.login.Configuration.Parameters):
    def __init__(self, uRI: java.net.URI): ...
    def getURI(self) -> java.net.URI: ...

class UnrecoverableEntryException(GeneralSecurityException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class AllPermission(Permission):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str, string2: str): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getActions(self) -> str: ...
    def hashCode(self) -> int: ...
    def implies(self, permission: Permission) -> bool: ...
    def newPermissionCollection(self) -> PermissionCollection: ...

class BasicPermission(Permission, java.io.Serializable):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getActions(self) -> str: ...
    def hashCode(self) -> int: ...
    def implies(self, permission: Permission) -> bool: ...
    def newPermissionCollection(self) -> PermissionCollection: ...

class IdentityScope(Identity):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, identityScope: 'IdentityScope'): ...
    def addIdentity(self, identity: Identity) -> None: ...
    @typing.overload
    def getIdentity(self, string: str) -> Identity: ...
    @typing.overload
    def getIdentity(self, publicKey: PublicKey) -> Identity: ...
    @typing.overload
    def getIdentity(self, principal: Principal) -> Identity: ...
    @staticmethod
    def getSystemScope() -> 'IdentityScope': ...
    def identities(self) -> java.util.Enumeration[Identity]: ...
    def removeIdentity(self, identity: Identity) -> None: ...
    def size(self) -> int: ...
    @typing.overload
    def toString(self, boolean: bool) -> str: ...
    @typing.overload
    def toString(self) -> str: ...

class InvalidKeyException(KeyException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class KeyManagementException(KeyException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, throwable: java.lang.Throwable): ...
    @typing.overload
    def __init__(self, throwable: java.lang.Throwable): ...

class Signer(Identity):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, identityScope: IdentityScope): ...
    def getPrivateKey(self) -> PrivateKey: ...
    def setKeyPair(self, keyPair: KeyPair) -> None: ...
    @typing.overload
    def toString(self, boolean: bool) -> str: ...
    @typing.overload
    def toString(self) -> str: ...

class UnrecoverableKeyException(UnrecoverableEntryException):
    @typing.overload
    def __init__(self): ...
    @typing.overload
    def __init__(self, string: str): ...

class UnresolvedPermission(Permission, java.io.Serializable):
    def __init__(self, string: str, string2: str, string3: str, certificateArray: typing.List[java.security.cert.Certificate]): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getActions(self) -> str: ...
    def getUnresolvedActions(self) -> str: ...
    def getUnresolvedCerts(self) -> typing.List[java.security.cert.Certificate]: ...
    def getUnresolvedName(self) -> str: ...
    def getUnresolvedType(self) -> str: ...
    def hashCode(self) -> int: ...
    def implies(self, permission: Permission) -> bool: ...
    def newPermissionCollection(self) -> PermissionCollection: ...
    def toString(self) -> str: ...

class SecurityPermission(BasicPermission):
    @typing.overload
    def __init__(self, string: str): ...
    @typing.overload
    def __init__(self, string: str, string2: str): ...

class DomainLoadStoreParameter(java.security.KeyStore.LoadStoreParameter):
    def __init__(self, uRI: java.net.URI, map: typing.Union[java.util.Map[str, 'KeyStore.ProtectionParameter'], typing.Mapping[str, 'KeyStore.ProtectionParameter']]): ...
    def getConfiguration(self) -> java.net.URI: ...
    def getProtectionParameter(self) -> 'KeyStore.ProtectionParameter': ...
    def getProtectionParams(self) -> java.util.Map[str, 'KeyStore.ProtectionParameter']: ...

class KeyStore:
    def aliases(self) -> java.util.Enumeration[str]: ...
    def containsAlias(self, string: str) -> bool: ...
    def deleteEntry(self, string: str) -> None: ...
    def entryInstanceOf(self, string: str, class_: typing.Type['KeyStore.Entry']) -> bool: ...
    def getCertificate(self, string: str) -> java.security.cert.Certificate: ...
    def getCertificateAlias(self, certificate: java.security.cert.Certificate) -> str: ...
    def getCertificateChain(self, string: str) -> typing.List[java.security.cert.Certificate]: ...
    def getCreationDate(self, string: str) -> java.util.Date: ...
    @staticmethod
    def getDefaultType() -> str: ...
    def getEntry(self, string: str, protectionParameter: 'KeyStore.ProtectionParameter') -> 'KeyStore.Entry': ...
    @typing.overload
    @staticmethod
    def getInstance(file: typing.Union[java.io.File, jpype.protocol.SupportsPath], charArray: typing.List[str]) -> 'KeyStore': ...
    @typing.overload
    @staticmethod
    def getInstance(file: typing.Union[java.io.File, jpype.protocol.SupportsPath], loadStoreParameter: 'KeyStore.LoadStoreParameter') -> 'KeyStore': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str) -> 'KeyStore': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, string2: str) -> 'KeyStore': ...
    @typing.overload
    @staticmethod
    def getInstance(string: str, provider: Provider) -> 'KeyStore': ...
    def getKey(self, string: str, charArray: typing.List[str]) -> Key: ...
    def getProvider(self) -> Provider: ...
    def getType(self) -> str: ...
    def isCertificateEntry(self, string: str) -> bool: ...
    def isKeyEntry(self, string: str) -> bool: ...
    @typing.overload
    def load(self, inputStream: java.io.InputStream, charArray: typing.List[str]) -> None: ...
    @typing.overload
    def load(self, loadStoreParameter: 'KeyStore.LoadStoreParameter') -> None: ...
    def setCertificateEntry(self, string: str, certificate: java.security.cert.Certificate) -> None: ...
    def setEntry(self, string: str, entry: 'KeyStore.Entry', protectionParameter: 'KeyStore.ProtectionParameter') -> None: ...
    @typing.overload
    def setKeyEntry(self, string: str, byteArray: typing.List[int], certificateArray: typing.List[java.security.cert.Certificate]) -> None: ...
    @typing.overload
    def setKeyEntry(self, string: str, key: Key, charArray: typing.List[str], certificateArray: typing.List[java.security.cert.Certificate]) -> None: ...
    def size(self) -> int: ...
    @typing.overload
    def store(self, outputStream: java.io.OutputStream, charArray: typing.List[str]) -> None: ...
    @typing.overload
    def store(self, loadStoreParameter: 'KeyStore.LoadStoreParameter') -> None: ...
    class Builder:
        def getKeyStore(self) -> 'KeyStore': ...
        def getProtectionParameter(self, string: str) -> 'KeyStore.ProtectionParameter': ...
        @typing.overload
        @staticmethod
        def newInstance(file: typing.Union[java.io.File, jpype.protocol.SupportsPath], protectionParameter: 'KeyStore.ProtectionParameter') -> 'KeyStore.Builder': ...
        @typing.overload
        @staticmethod
        def newInstance(string: str, provider: Provider, file: typing.Union[java.io.File, jpype.protocol.SupportsPath], protectionParameter: 'KeyStore.ProtectionParameter') -> 'KeyStore.Builder': ...
        @typing.overload
        @staticmethod
        def newInstance(string: str, provider: Provider, protectionParameter: 'KeyStore.ProtectionParameter') -> 'KeyStore.Builder': ...
        @typing.overload
        @staticmethod
        def newInstance(keyStore: 'KeyStore', protectionParameter: 'KeyStore.ProtectionParameter') -> 'KeyStore.Builder': ...
    class CallbackHandlerProtection(java.security.KeyStore.ProtectionParameter):
        def __init__(self, callbackHandler: javax.security.auth.callback.CallbackHandler): ...
        def getCallbackHandler(self) -> javax.security.auth.callback.CallbackHandler: ...
    class Entry:
        def getAttributes(self) -> java.util.Set['KeyStore.Entry.Attribute']: ...
        class Attribute:
            def getName(self) -> str: ...
            def getValue(self) -> str: ...
    class LoadStoreParameter:
        def getProtectionParameter(self) -> 'KeyStore.ProtectionParameter': ...
    class PasswordProtection(java.security.KeyStore.ProtectionParameter, javax.security.auth.Destroyable):
        @typing.overload
        def __init__(self, charArray: typing.List[str]): ...
        @typing.overload
        def __init__(self, charArray: typing.List[str], string: str, algorithmParameterSpec: java.security.spec.AlgorithmParameterSpec): ...
        def destroy(self) -> None: ...
        def getPassword(self) -> typing.List[str]: ...
        def getProtectionAlgorithm(self) -> str: ...
        def getProtectionParameters(self) -> java.security.spec.AlgorithmParameterSpec: ...
        def isDestroyed(self) -> bool: ...
    class PrivateKeyEntry(java.security.KeyStore.Entry):
        @typing.overload
        def __init__(self, privateKey: PrivateKey, certificateArray: typing.List[java.security.cert.Certificate]): ...
        @typing.overload
        def __init__(self, privateKey: PrivateKey, certificateArray: typing.List[java.security.cert.Certificate], set: java.util.Set['KeyStore.Entry.Attribute']): ...
        def getAttributes(self) -> java.util.Set['KeyStore.Entry.Attribute']: ...
        def getCertificate(self) -> java.security.cert.Certificate: ...
        def getCertificateChain(self) -> typing.List[java.security.cert.Certificate]: ...
        def getPrivateKey(self) -> PrivateKey: ...
        def toString(self) -> str: ...
    class ProtectionParameter: ...
    class SecretKeyEntry(java.security.KeyStore.Entry):
        @typing.overload
        def __init__(self, secretKey: javax.crypto.SecretKey): ...
        @typing.overload
        def __init__(self, secretKey: javax.crypto.SecretKey, set: java.util.Set['KeyStore.Entry.Attribute']): ...
        def getAttributes(self) -> java.util.Set['KeyStore.Entry.Attribute']: ...
        def getSecretKey(self) -> javax.crypto.SecretKey: ...
        def toString(self) -> str: ...
    class TrustedCertificateEntry(java.security.KeyStore.Entry):
        @typing.overload
        def __init__(self, certificate: java.security.cert.Certificate): ...
        @typing.overload
        def __init__(self, certificate: java.security.cert.Certificate, set: java.util.Set['KeyStore.Entry.Attribute']): ...
        def getAttributes(self) -> java.util.Set['KeyStore.Entry.Attribute']: ...
        def getTrustedCertificate(self) -> java.security.cert.Certificate: ...
        def toString(self) -> str: ...

class PKCS12Attribute(KeyStore.Entry.Attribute):
    @typing.overload
    def __init__(self, byteArray: typing.List[int]): ...
    @typing.overload
    def __init__(self, string: str, string2: str): ...
    def equals(self, object: typing.Any) -> bool: ...
    def getEncoded(self) -> typing.List[int]: ...
    def getName(self) -> str: ...
    def getValue(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("java.security")``.

    AccessControlContext: typing.Type[AccessControlContext]
    AccessControlException: typing.Type[AccessControlException]
    AccessController: typing.Type[AccessController]
    AlgorithmConstraints: typing.Type[AlgorithmConstraints]
    AlgorithmParameterGenerator: typing.Type[AlgorithmParameterGenerator]
    AlgorithmParameterGeneratorSpi: typing.Type[AlgorithmParameterGeneratorSpi]
    AlgorithmParameters: typing.Type[AlgorithmParameters]
    AlgorithmParametersSpi: typing.Type[AlgorithmParametersSpi]
    AllPermission: typing.Type[AllPermission]
    AuthProvider: typing.Type[AuthProvider]
    BasicPermission: typing.Type[BasicPermission]
    Certificate: typing.Type[Certificate]
    CodeSigner: typing.Type[CodeSigner]
    CodeSource: typing.Type[CodeSource]
    CryptoPrimitive: typing.Type[CryptoPrimitive]
    DigestException: typing.Type[DigestException]
    DigestInputStream: typing.Type[DigestInputStream]
    DigestOutputStream: typing.Type[DigestOutputStream]
    DomainCombiner: typing.Type[DomainCombiner]
    DomainLoadStoreParameter: typing.Type[DomainLoadStoreParameter]
    DrbgParameters: typing.Type[DrbgParameters]
    GeneralSecurityException: typing.Type[GeneralSecurityException]
    Guard: typing.Type[Guard]
    GuardedObject: typing.Type[GuardedObject]
    Identity: typing.Type[Identity]
    IdentityScope: typing.Type[IdentityScope]
    InvalidAlgorithmParameterException: typing.Type[InvalidAlgorithmParameterException]
    InvalidKeyException: typing.Type[InvalidKeyException]
    InvalidParameterException: typing.Type[InvalidParameterException]
    Key: typing.Type[Key]
    KeyException: typing.Type[KeyException]
    KeyFactory: typing.Type[KeyFactory]
    KeyFactorySpi: typing.Type[KeyFactorySpi]
    KeyManagementException: typing.Type[KeyManagementException]
    KeyPair: typing.Type[KeyPair]
    KeyPairGenerator: typing.Type[KeyPairGenerator]
    KeyPairGeneratorSpi: typing.Type[KeyPairGeneratorSpi]
    KeyRep: typing.Type[KeyRep]
    KeyStore: typing.Type[KeyStore]
    KeyStoreException: typing.Type[KeyStoreException]
    KeyStoreSpi: typing.Type[KeyStoreSpi]
    MessageDigest: typing.Type[MessageDigest]
    MessageDigestSpi: typing.Type[MessageDigestSpi]
    NoSuchAlgorithmException: typing.Type[NoSuchAlgorithmException]
    NoSuchProviderException: typing.Type[NoSuchProviderException]
    PKCS12Attribute: typing.Type[PKCS12Attribute]
    Permission: typing.Type[Permission]
    PermissionCollection: typing.Type[PermissionCollection]
    Permissions: typing.Type[Permissions]
    Policy: typing.Type[Policy]
    PolicySpi: typing.Type[PolicySpi]
    Principal: typing.Type[Principal]
    PrivateKey: typing.Type[PrivateKey]
    PrivilegedAction: typing.Type[PrivilegedAction]
    PrivilegedActionException: typing.Type[PrivilegedActionException]
    PrivilegedExceptionAction: typing.Type[PrivilegedExceptionAction]
    ProtectionDomain: typing.Type[ProtectionDomain]
    Provider: typing.Type[Provider]
    ProviderException: typing.Type[ProviderException]
    PublicKey: typing.Type[PublicKey]
    SecureClassLoader: typing.Type[SecureClassLoader]
    SecureRandom: typing.Type[SecureRandom]
    SecureRandomParameters: typing.Type[SecureRandomParameters]
    SecureRandomSpi: typing.Type[SecureRandomSpi]
    Security: typing.Type[Security]
    SecurityPermission: typing.Type[SecurityPermission]
    Signature: typing.Type[Signature]
    SignatureException: typing.Type[SignatureException]
    SignatureSpi: typing.Type[SignatureSpi]
    SignedObject: typing.Type[SignedObject]
    Signer: typing.Type[Signer]
    Timestamp: typing.Type[Timestamp]
    URIParameter: typing.Type[URIParameter]
    UnrecoverableEntryException: typing.Type[UnrecoverableEntryException]
    UnrecoverableKeyException: typing.Type[UnrecoverableKeyException]
    UnresolvedPermission: typing.Type[UnresolvedPermission]
    acl: java.security.acl.__module_protocol__
    cert: java.security.cert.__module_protocol__
    interfaces: java.security.interfaces.__module_protocol__
    spec: java.security.spec.__module_protocol__



import java.lang
import org.ergoplatform.appkit.cli
import org.ergoplatform.appkit.commands
import org.ergoplatform.appkit.config
import scala
import scala.collection
import typing



class HelpCmd(org.ergoplatform.appkit.commands.Cmd, scala.Product, scala.Serializable):
    def __init__(self, toolConf: org.ergoplatform.appkit.config.ErgoToolConfig, name: typing.Union[java.lang.String, str], askedCmd: typing.Union[java.lang.String, str]): ...
    @staticmethod
    def BaseDocUrl() -> java.lang.String: ...
    @staticmethod
    def apply(toolConf: org.ergoplatform.appkit.config.ErgoToolConfig, name: typing.Union[java.lang.String, str], askedCmd: typing.Union[java.lang.String, str]) -> 'HelpCmd': ...
    def askedCmd(self) -> java.lang.String: ...
    def canEqual(self, x$1: typing.Any) -> bool: ...
    @staticmethod
    def cmdParamSyntax() -> java.lang.String: ...
    def copy(self, toolConf: org.ergoplatform.appkit.config.ErgoToolConfig, name: typing.Union[java.lang.String, str], askedCmd: typing.Union[java.lang.String, str]) -> 'HelpCmd': ...
    def copy$default$1(self) -> org.ergoplatform.appkit.config.ErgoToolConfig: ...
    def copy$default$2(self) -> java.lang.String: ...
    def copy$default$3(self) -> java.lang.String: ...
    @staticmethod
    def createCmd(ctx: org.ergoplatform.appkit.cli.AppContext) -> org.ergoplatform.appkit.commands.Cmd: ...
    @staticmethod
    def description() -> java.lang.String: ...
    @staticmethod
    def docUrl() -> java.lang.String: ...
    def equals(self, x$1: typing.Any) -> bool: ...
    def hashCode(self) -> int: ...
    def name(self) -> java.lang.String: ...
    @staticmethod
    def parameters() -> scala.collection.Seq[org.ergoplatform.appkit.commands.CmdParameter]: ...
    @staticmethod
    def parseArgs(ctx: org.ergoplatform.appkit.cli.AppContext, args: scala.collection.Seq[typing.Union[java.lang.String, str]]) -> scala.collection.Seq[typing.Any]: ...
    @staticmethod
    def printUsage(console: org.ergoplatform.appkit.cli.Console) -> org.ergoplatform.appkit.cli.Console: ...
    def productArity(self) -> int: ...
    def productElement(self, x$1: int) -> typing.Any: ...
    def productIterator(self) -> scala.collection.Iterator[typing.Any]: ...
    def productPrefix(self) -> java.lang.String: ...
    def run(self, ctx: org.ergoplatform.appkit.cli.AppContext) -> None: ...
    def toString(self) -> java.lang.String: ...
    def toolConf(self) -> org.ergoplatform.appkit.config.ErgoToolConfig: ...
    @staticmethod
    def unapply(x$0: 'HelpCmd') -> scala.Option[scala.Tuple3[org.ergoplatform.appkit.config.ErgoToolConfig, java.lang.String, java.lang.String]]: ...


class __module_protocol__(typing.Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("org.ergoplatform.appkit.ergotool")``.

    HelpCmd: typing.Type[HelpCmd]
